	.file	"abs.c"
	.text
	.p2align 2,,3
.globl less
	.type	less,@function
less:
	pushl	%ebp
	movl	%esp, %ebp
	movl	12(%ebp), %eax
	cmpl	%eax, 8(%ebp)
	setl	%al
	movzbl	%al, %eax
	leave
	ret
.Lfe1:
	.size	less,.Lfe1-less
	.p2align 2,,3
.globl absdiff
	.type	absdiff,@function
absdiff:
	pushl	%ebp
	movl	%esp, %ebp
	movl	8(%ebp), %edx
	movl	12(%ebp), %eax
	cmpl	%eax, %edx
	jge	.L3
	subl	%edx, %eax
.L2:
	leave
	ret
	.p2align 2,,3
.L3:
	subl	%eax, %edx
	movl	%edx, %eax
	jmp	.L2
.Lfe2:
	.size	absdiff,.Lfe2-absdiff
	.ident	"GCC: (GNU) 3.2.2 20030222 (Red Hat Linux 3.2.2-5)"
