typedef enum {ADD, MULT, MINUS, DIV, MOD} op_type;

char unparse(op_type op)
{
  switch (op) {
  case ADD:
    return '+';
  case MULT:
    return '*';
  case MINUS:
    return '-';
  case DIV:
    return '/';
  case MOD:
    return '%';
  default:
    return '?';
  }
}

int main()
{
  char sym;
  op_type op;
 loop:				/* use goto just for fun! */
  scanf("%d", &op);		/* read integer */
  if (op == -1) return 0;	/* exit if -1 */
  sym = unparse(op);		/* unparse into character */
  printf("%c\n", sym);		/* print character */
  goto loop;			/* continue to read/print */
}
