	.file	"switch.c"
	.text
	.p2align 2,,3
.globl unparse
	.type	unparse,@function
unparse:
	pushl	%ebp
	movl	%esp, %ebp
	movl	8(%ebp), %edx
	cmpl	$4, %edx
	movl	$63, %eax
	ja	.L1
	jmp	*.L9(,%edx,4)
	.section	.rodata
	.align 4
	.align 4
.L9:
	.long	.L3
	.long	.L4
	.long	.L5
	.long	.L6
	.long	.L7
	.text
.L3:
	movl	$43, %eax
	.p2align 2,,3
.L1:
	leave
	ret
.L4:
	movl	$42, %eax
	jmp	.L1
.L5:
	movl	$45, %eax
	jmp	.L1
.L6:
	movl	$47, %eax
	jmp	.L1
.L7:
	movl	$37, %eax
	jmp	.L1
.Lfe1:
	.size	unparse,.Lfe1-unparse
	.section	.rodata.str1.1,"aMS",@progbits,1
.LC0:
	.string	"%d"
.LC1:
	.string	"%c\n"
	.text
	.p2align 2,,3
.globl main
	.type	main,@function
main:
	pushl	%ebp
	movl	%esp, %ebp
	pushl	%ebx
	pushl	%ebx
	andl	$-16, %esp
	leal	-8(%ebp), %ebx
	.p2align 2,,3
.L11:
	subl	$8, %esp
	pushl	%ebx
	pushl	$.LC0
	call	scanf
	movl	-8(%ebp), %eax
	addl	$16, %esp
	cmpl	$-1, %eax
	je	.L13
	subl	$12, %esp
	pushl	%eax
	call	unparse
	popl	%edx
	popl	%ecx
	movsbl	%al,%eax
	pushl	%eax
	pushl	$.LC1
	call	printf
	addl	$16, %esp
	jmp	.L11
.L13:
	xorl	%eax, %eax
	movl	-4(%ebp), %ebx
	leave
	ret
.Lfe2:
	.size	main,.Lfe2-main
	.ident	"GCC: (GNU) 3.2.2 20030222 (Red Hat Linux 3.2.2-5)"
